import React from 'react';
import { Grid } from "@material-ui/core";
import { Alert } from "@material-ui/lab";
import {iocHasNameDeviation} from '../../components/common/Helper.js';

export default function IOCAlerts({ioc}) {
  const repoDirtyUnknown = <Alert severity="error">Git repository dirty state: unknown</Alert>;
  const essiocUnknown = <Alert severity="error">essioc state is unknown</Alert>;
  const repoLocalCommitUnknown = <Alert severity="error">Git repository localcommit state: unknown</Alert>;
  const cellmodeUnknown = <Alert severity="error">Cellmode state: unknown</Alert>;
  const iocServiceUnknown = <Alert severity="error">IOC service state: unknown</Alert>;
  const gitDirtyAlert = <Alert severity="warning">IOC repository is dirty</Alert>;
  const gitLocalCommitAlert = <Alert severity="warning">Git repo has local (unpushed) commits</Alert>;
  const essiocMissingAlert = <Alert severity="warning">essioc is not or incorrectly used</Alert>;
  const cellmodeUsedAlert = <Alert severity="warning">Cellmode is used</Alert>;
  const iocServiceDisabledAlert = <Alert severity="warning">IOC service is deactivated</Alert>;
  const nameChangeInCcdbAlert = <Alert severity="warning">IOC name changed in CCDB</Alert>;
  const nameChangeInNamingAlert = <Alert severity="warning">IOC name changed in Naming service</Alert>;
  const latestDeploymentFailedAlert = <Alert severity="error">IOC&apos;s latest deployment was failed, IOC may be in inconsistent state</Alert>;
  const latestUndeploymentFailedAlert = <Alert severity="error">IOC&apos;s latest undeployment was failed, IOC may be in inconsistent state</Alert>;
  const nameDiffersFromDeployedVersion = <Alert severity="warning">IOC is deployed with a different name</Alert>;
  const iocNotDeployed = <Alert severity="warning">IOC is not yet deployed</Alert>;

  return (
    <Grid container spacing={1}>
        {(ioc.latestDeployment && !ioc.latestDeployment.undeployment && ioc.latestDeployment.status !== "SUCCESSFUL") && 
          <Grid item xs={12}>
            {latestDeploymentFailedAlert}
          </Grid>
        }
        {(ioc.latestDeployment && ioc.latestDeployment.undeployment && ioc.latestDeployment.status !== "SUCCESSFUL") && 
          <Grid item xs={12}>
            {latestUndeploymentFailedAlert}
          </Grid>
        }
        {(!ioc.activeDeployment) &&
          <Grid item xs={12}>
            {iocNotDeployed}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.hasLocalCommits === null) && 
          <Grid item xs={12}>
            {repoLocalCommitUnknown}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.dirty === null) && 
          <Grid item xs={12}>
            {repoDirtyUnknown}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.serviceDisabled === null) && 
          <Grid item xs={12}>
            {iocServiceUnknown}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.essiocMissing === null) && 
          <Grid item xs={12}>
            {essiocUnknown}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.cellmodeUsed === null) && 
          <Grid item xs={12}>
            {cellmodeUnknown}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.hasLocalCommits) && 
          <Grid item xs={12}>
            {gitLocalCommitAlert}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.dirty) && 
          <Grid item xs={12}>
            {gitDirtyAlert}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.serviceDisabled) && 
          <Grid item xs={12}>
            {iocServiceDisabledAlert}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.essiocMissing) && 
          <Grid item xs={12}>
            {essiocMissingAlert}
          </Grid>
        }
        {(ioc.activeDeployment?.undeployment === false && ioc.cellmodeUsed) && 
          <Grid item xs={12}>
            {cellmodeUsedAlert}
          </Grid>
        }
        {(ioc.nameChangedInCCDB) && 
          <Grid item xs={12}>
            {nameChangeInCcdbAlert}
          </Grid>
        }
        {(ioc.nameChangedInNaming) && 
          <Grid item xs={12}>
            {nameChangeInNamingAlert}
          </Grid>
        }

        {(iocHasNameDeviation(ioc)) &&
          <Grid item xs={12}>
            {nameDiffersFromDeployedVersion}
          </Grid>
        }
    </Grid>)
}