import React from 'react';
import { Box } from "@material-ui/core";
import { CustomTable } from "../common/table/CustomTable";
import { DeploymentStatusIcon } from '../deployments/DeploymentIcons';
import { CommandTypeIcon } from './IOCIcons';
import { formatDate } from '../common/Helper';

const formatCommandDate = (value) => {
    if (value) {
      return formatDate(value);
    }
    return "Not started yet";
}

const dateTemplate = (rowData) => {
    return formatCommandDate(rowData.start);
}

const columns = [
  { id: "status", label: 'Status', width: '10%' },
  { id: "type", label: 'Command', width: '10%' },
  { id: "user", label: 'User', width: '40%', sortable: true },
  { id: 'start', label: 'Timestamp', width: '40%', body: dateTemplate, sortable: true }
]

function createTableRow(command) {
  return { 
    id:command.id,
    type:
      <Box display="flex" justifyContent="center" p={2} m={1}>
        <CommandTypeIcon type={command.type}/>
      </Box>,
    status: 
      <Box display="flex" justifyContent="center" p={2} m={1}>
        <DeploymentStatusIcon status={command.status}/>
      </Box>, 
    user: command.createdBy,
    start: command.startDate,
  };
}

export function IOCCommandTable({ commands }) {
  
  return (
    <CustomTable columns={columns} rows={commands.map(command => createTableRow(command))} rowsPerPage={5} />
  );
}