import React, { useEffect, useState } from "react";
import { Button, TextField, Dialog, DialogActions, DialogContent, DialogTitle, makeStyles } from "@material-ui/core";
import { Autocomplete, Alert } from "@material-ui/lab";
import { useNamingNames, useAllowedGitProjects } from "../../api/SwaggerApi";
import { useTypingTimer } from "../common/SearchBoxFilter/TypingTimer";

const useStyles = makeStyles((theme) => ({
  textField: {
    marginBottom: theme.spacing(1),
  },
}));

export function IOCCreateDialog({ open, setOpen, submitCallback, error, resetError }) {
  const classes = useStyles();
  const [names, getNames] = useNamingNames();
  const [name, setName] = useState();
  const [nameQuery, onNameKeyUp] = useTypingTimer({interval: 500});
  const [allowedGitProjects, getAllowedGitProjects] = useAllowedGitProjects();
  const [gitUrl, setGitUrl] = useState();

  const handleClose = () => {
    setOpen(false);
  };

  console.log("Name: " + JSON.stringify(name));

  useEffect(() => getNames(nameQuery), [nameQuery, getNames]);

  useEffect(() => {
    getAllowedGitProjects();
  }, [getAllowedGitProjects]);

  const onSubmit = (event) => {
    event.preventDefault();

    submitCallback({
        sourceUrl: gitUrl,
        externalNameId: name ? parseInt(name.id) : undefined });
  };

  return (
    <Dialog open={open} onClose={handleClose} fullWidth maxWidth="sm">
      <form onSubmit={onSubmit}>
        <DialogTitle id="form-dialog-title" data-testid="create-dialog-title">Create new IOC</DialogTitle>
        <DialogContent>
          <Autocomplete
            className={classes.textField}
            autoHighlight
            id="nameAutocomplete"
            options={names}
            getOptionLabel={(option) => {console.log(option?.name); return option?.name}}
            renderInput={(params) => <TextField {...params} label="IOC name" variant="outlined" required/>}
            onChange={(event, value, reason) => {setName(value); resetError();}}
            onInputChange={(event, value, reason) => {event && onNameKeyUp(event.nativeEvent)}}
          />

          <TextField autoComplete="off" className={classes.textField} id="description" label="--- IOC Description from CCDB ---"
            variant="standard" fullWidth disabled value={name? name.description : ""} />
          
          <Autocomplete
            className={classes.textField}
            autoHighlight
            id="version"
            options={allowedGitProjects}
            defaultValue = { "" }
            getOptionLabel={(option) => {return option}}
            onChange={(event, value, reason) => {setGitUrl(value); resetError();}}
            renderInput={(params) => <TextField {...params} label="Git repository" variant="outlined" fullWidth required />}
          />

          {error ?
            <Alert severity="error">{error}</Alert>
          : <></>}

        </DialogContent>
        <DialogActions>
          <Button onClick={handleClose} color="primary">Cancel</Button>
          <Button color="primary" variant="contained" type="submit">Create</Button>
        </DialogActions>
      </form>
    </Dialog>
  );
}