import React, { useState, useEffect, useRef } from 'react';
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { Button, makeStyles, TextField, Typography } from "@material-ui/core";
import { Autocomplete, Alert } from "@material-ui/lab";
import { useAllowedGitProjects, useNamingNames, useUpdateIoc } from "../../api/SwaggerApi";
import { useTypingTimer } from "../common/SearchBoxFilter/TypingTimer";
import { ConfirmationDialog } from "../dialog/ConfirmationDialog";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";

const useStyles = makeStyles((theme) => ({
    textField: {
        marginBottom: theme.spacing(1),
    },
}));

export default function IOCDetailAdmin({ ioc, getIOC, resetTab }) {
    const classes = useStyles();

    const [gitUrl, setGitUrl] = useState(ioc.sourceUrl);
    const [allowedGitProjects, getAllowedGitProjects] = useAllowedGitProjects();
    const [nameQuery, onNameKeyUp] = useTypingTimer({ interval: 500 });
    const [names, getNames] = useNamingNames();
    const [name, setName] = useState({ id: ioc.externalNameId, description: ioc.description, name: ioc.namingName });
    const [owner, setOwner] = useState(ioc.owner);

    //for the dialog
    const [adHocDialogOpen, setAdHocDialogOpen] = useState(false);
    const [adHocDialogTitle, setAdHocDiatlogTitle] = useState();
    const [adHocDialogDescription, setAdHocDialogDescription] = useState();
    const [error, setError] = useState();
    const callbackRef = useRef();

    function onError(message) {
        setError(message);
    }  

    const [uioc, actionUpdateIoc] = useUpdateIoc(ioc.id, onError);

    useEffect(() => {
        getAllowedGitProjects();
    }, [getAllowedGitProjects]);

    useEffect(() => getNames(nameQuery), [nameQuery, getNames]);

    //when user clicks Submit button a dialog should open
    const onSubmit = (event) => {
        event.preventDefault();

        openModifyModal();
    }

    //Setting up dialog properties
    const openModifyModal = () => {
        setAdHocDiatlogTitle("Modifying IOC");
        setAdHocDialogDescription(
            <>
                <Typography style={{ display: 'inline-block' }}>Are you sure want to modify &nbsp;</Typography>
                <Typography style={{ fontFamily: "monospace", display: 'inline-block' }}> {ioc.namingName}? </Typography>
            </>);
        callbackRef.current = modifyIoc;
        setAdHocDialogOpen(true);
    }

    //what to do when modifying IOC
    const modifyIoc = () => {

         actionUpdateIoc({
            owner: owner,
            sourceUrl: gitUrl,
            externalNameId: name ? parseInt(name.id) : null
        });
    }

    useEffect(() => 
    {
      if(uioc) {
        getIOC();
        resetTab();
      }
    }, [uioc, getIOC, resetTab]);

    return (
        <>
            <SimpleModal open={adHocDialogOpen} setOpen={setAdHocDialogOpen}>
                <ConfirmationDialog open={adHocDialogOpen} setOpen={setAdHocDialogOpen} title={adHocDialogTitle} description={adHocDialogDescription} callback={callbackRef.current} />
            </SimpleModal>

            <SimpleAccordion summary="Modify IOC" defaultExpanded>
                <form onSubmit={onSubmit} style={{ width: "100%" }}>
                    <Autocomplete
                        className={classes.textField}
                        autoHighlight
                        id="namingName"
                        options={names}
                        defaultValue={name}
                        getOptionLabel={(option) => { console.log(option?.name); return option?.name }}
                        renderInput={(params) => <TextField {...params} label="IOC name" variant="outlined" required />}
                        onChange={(event, value, reason) => {setName(value); setError(null);}}
                        onInputChange={(event, value, reason) => { event && onNameKeyUp(event.nativeEvent) }}
                    />

                    <Autocomplete
                        className={classes.textField}
                        autoHighlight
                        id="gitUrl"
                        options={allowedGitProjects}
                        defaultValue={gitUrl}
                        getOptionLabel={(option) => { return option }}
                        onChange={(event, value, reason) => {setGitUrl(value); setError(null);}}
                        renderInput={(params) => <TextField {...params} label="Git repository" variant="outlined" fullWidth required />} />

                    <TextField id="owner" className={classes.textField} label="Owner" variant="outlined" fullWidth required value={owner} onChange={(event) => {setOwner(event.target.value); setError(null);}} />

                    {error ?
                        <Alert severity="error">{error}</Alert>
                    : <></>}

                    <br /><br />
                    <Button color="primary" variant="contained" type="submit">Modify IOC</Button>
                </form>
            </SimpleAccordion>
        </>
    )
}