import { Typography, Container, Button } from "@material-ui/core";
import React, { useState, useEffect } from "react";
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { IOCDetails } from "./IOCDetails";
import { Link } from 'react-router-dom';
import { LokiPanel } from "../common/Loki/LokiPanel";
import { useHost, useCommandList } from '../../api/SwaggerApi';
import GitRefLink from "./GitRefLink";
import IOCAlerts from "./IOCAlerts";
import { IOCService } from "./IOCService";
import { IOCCommandTable } from "./IOCCommandTable";
import { Launch } from '@material-ui/icons';
import { LokiDialog } from '../common/Loki/LokiDialog';
import { SimpleModal } from "../common/SimpleModal/SimpleModal";


export function IOCLiveStatus({ ioc, getIOC }) {
  const liveIOC = { ...ioc };
  liveIOC.host = ioc.activeDeployment.host.host;
  liveIOC.name = ioc.namingName;

  const [commands, getCommands] = useCommandList(liveIOC.activeDeployment?.id);
  const [ongoingCommand, setOngoingCommand] = useState(null);
  const [logDialogOpen, setLogDialogOpen] = useState(false);

  useEffect(() => {
    if (commands && commands.length > 0 && !["successful", "failed"].includes(commands[0].status?.toLowerCase())) {
      setOngoingCommand(commands[0]);
    } else {
      setOngoingCommand(null);
    }
  }, [commands, setOngoingCommand]);

  const getSubset = (ioc) => {
    const { description, activeDeployment } = ioc;
    //Show START/STOP components only when IOC was deployed SUCCESSFULLY
    const showControlls = Boolean(activeDeployment) && activeDeployment?.status === 'SUCCESSFUL';

    return ({
      "Git reference": <GitRefLink ioc={ioc} />,
      description,
      "Deployed on": <Typography><Link to={`/hosts/${ioc.activeDeployment.host.csEntryId}`}>{ioc.activeDeployment.host.host}</Link></Typography>,
      "IOC Service Controls": showControlls ? <IOCService ioc={ioc} getIOC={getIOC} ongoingCommand={ongoingCommand} getCommands={getCommands}  /> : "Can't be controlled, because IOC is not (yet) deployed succesfully",
      /*"Open IOC host in CSentry": <a href={`https://csentry.esss.lu.se/network/hosts/view/${hostName}`} target="_blank" rel="noreferrer">{`https://csentry.esss.lu.se/network/hosts/view/${hostName}`}</a>,
      "Host status": status?.toLowerCase(),*/
    })
  };

  const [iocHost] = useHost(liveIOC.activeDeployment?.host.csEntryId);
  
  const closeLogDialogModal = () => {
    setLogDialogOpen(false);
  }

  const onDialogPopUp = () => {
    setLogDialogOpen(true);
  }

  function isIocDeployed(ioc) {
    return Boolean(ioc.activeDeployment);
  }

  return (
    <>
      <SimpleModal open={logDialogOpen} setOpen={setLogDialogOpen}>
        <LokiDialog open={logDialogOpen} setOpen={setLogDialogOpen} submitCallback={closeLogDialogModal} host={iocHost} isSyslog={false} 
          isDeployed={isIocDeployed(ioc)} iocName={ioc.namingName} />
      </SimpleModal>

      <IOCDetails ioc={liveIOC} getSubset={getSubset} alert={<IOCAlerts ioc={liveIOC}/>}/>
      <SimpleAccordion summary="IOC Service Control log">
        <IOCCommandTable commands={commands} />
      </SimpleAccordion>
      <SimpleAccordion summary="ProcServLog info" defaultExpanded>
        {iocHost && 
        
        <Container>
            <Button color="inherit" variant="outlined" endIcon={<Launch />} style={{float: 'right'}} onClick={onDialogPopUp}>Popout log</Button>
            <LokiPanel host={iocHost} isSyslog={false} iocName={ioc.namingName} isDeployed={isIocDeployed(ioc)} />  
        </Container>
        }
      </SimpleAccordion>
    </>
  );
}
