import { Button, Link as MuiLink, Typography } from "@material-ui/core";
import React, { useState, useEffect } from "react";
import { IOCDetails } from "../../components/IOC/IOCDetails";
import { DeployIOC } from "../../components/IOC/DeployIOC";
import { UndeployIOC } from "../../components/IOC/UndeployIOC";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { useUpdateAndDeployIoc, useCreateUndeployment, useDeploymentListForIOC } from "../../api/SwaggerApi";
import GitRefLink from "./GitRefLink";
import IOCAlerts from "./IOCAlerts";
import { Link } from 'react-router-dom';
import { DeploymentsTable } from "../../components/deployments/DeploymentsTable";
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";

export function IOCManage({ ioc, getIOC }) {
  const [deployDialogOpen, setDeployDialogOpen] = useState(false);
  const [undeployDialogOpen, setUndeployDialogOpen] = useState(false);
  const [deployments, getDeployments] = useDeploymentListForIOC();

  useEffect(() => 
    {
      if(ioc) {
        getDeployments(`${ioc.id}`)
      }
    }, [ioc, getDeployments]);

  const closeDeployModal = () => {
    setDeployDialogOpen(false);
    getIOC();
    // history.push(window.location.pathname);
  }

  const closeUndeployModal = () => {
    setUndeployDialogOpen(false);
  }

  let content = <></>;
  if (ioc) {
    console.log({ ...ioc });
    const managedIOC = { ...ioc };
    managedIOC.host = ioc.activeDeployment?.host.host;

    const getSubset = (ioc) => {
      ioc = { ...ioc };
      const {
        description,
        // active, 
      } = ioc;
      const { sourceUrl: git } = ioc;
      let host = ioc.activeDeployment?.host.host;

      //create link if host is set
      if (ioc.activeDeployment) {
        host = <Typography><Link to={`/hosts/${ioc.activeDeployment.host.csEntryId}`}>{ioc.activeDeployment.host.host}</Link></Typography>
      }

      return {
        "CCDB name": <Typography><MuiLink href={`${window.CCDB_ADDRESS}?name=${ioc.namingName}`} 
                        target="_blank" rel="noreferrer">{ioc.namingName}</MuiLink></Typography>,
        description,
        git: <Typography><MuiLink href={git} target="_blank" rel="noreferrer">{git}</MuiLink></Typography>,
        "Git reference" : ioc.sourceVersion ? <GitRefLink ioc={ioc} /> : '---',
        "target host": host || '---',
      };
    };

    const formInit = {
      name: ioc.namingName,
      description: ioc.description,
      version: ioc.sourceVersion,
      shortVersion: ioc.sourceVersionShort,
      git: ioc.sourceUrl,
    };

    if (ioc.activeDeployment) {
      formInit.csEntryHost = {
        fqdn: ioc.activeDeployment.host.host,
        id: ioc.activeDeployment.host.csEntryId,
      }
    }

    content = (
      <>
        <IOCDetails ioc={managedIOC} getSubset={getSubset} alert={<IOCAlerts ioc={managedIOC}/>}
          buttons={
            <>
              <Button variant="contained" color="secondary" onClick={() => { setDeployDialogOpen(true) }}>
                {ioc.activeDeployment ? "Deploy new revision" : "Deploy"}
              </Button>
              {ioc.activeDeployment ? 
                <Button variant="contained" color="secondary" style={{ marginRight: 20 }} onClick={() => { setUndeployDialogOpen(true) }}>Undeploy</Button> :
                <></> 
              }
            </>
          } 
        />
        <SimpleAccordion summary="Deployment log">
          <DeploymentsTable deployments={deployments} rowsPerPage={5}/>
        </SimpleAccordion>
        <SimpleModal open={deployDialogOpen} setOpen={setDeployDialogOpen}>
          <DeployIOC open={deployDialogOpen} setOpen={setDeployDialogOpen} submitCallback={closeDeployModal} init={formInit} hook={useUpdateAndDeployIoc.bind(null, ioc.id)}
            hasActiveDeployment={ioc.activeDeployment} />
        </SimpleModal>
        <SimpleModal open={undeployDialogOpen} setOpen={setUndeployDialogOpen}>
          <UndeployIOC open={undeployDialogOpen} setOpen={setUndeployDialogOpen} submitCallback={closeUndeployModal} ioc={ioc} hook={useCreateUndeployment.bind(null, ioc.id)} />
        </SimpleModal>
      </>
    );
  }

  return (
    <>
      {content}
    </>
  );

}