import React from "react";
import { Button, TextField, Dialog, DialogActions, DialogContent, DialogTitle, DialogContentText, makeStyles } from "@material-ui/core";
import { Alert } from "@material-ui/lab";

const useStyles = makeStyles((theme) => ({
  textField: {
    marginBottom: theme.spacing(1),
  },
}));

export function IOCUndeployDialog({ open, setOpen, submitCallback, ioc , error }) {
  const classes = useStyles();

  const handleClose = () => {
    setOpen(false);
  };

  const onSubmit = (event) => {
    event.preventDefault();
    const { comment: commentText } = event.currentTarget.elements;
    const comment = commentText.value;

    submitCallback({
      comment: comment});
  };

  return (
    <Dialog open={open} onClose={handleClose}>
      <form onSubmit={onSubmit}>
        <DialogTitle id="form-dialog-title">Undeploy</DialogTitle>
        <DialogContent>
          <DialogContentText>
            Do you really want to undeploy {ioc.namingName} from {ioc.activeDeployment.host.host}?
          </DialogContentText>
          <TextField autoComplete="off" className={classes.textField} id="comment" label="Undeployment comment" variant="outlined" fullWidth/>
          {error ?
            <Alert severity="error"className={classes.alert}>{error}</Alert>
          : <></>}
        </DialogContent>
        <DialogActions>
          <Button onClick={handleClose} color="primary">Cancel</Button>
          <Button color="primary" variant="contained" type="submit">Undeploy</Button>
        </DialogActions>
      </form>
    </Dialog>
  );
}
