import React, { useState, useRef, useEffect } from "react";
import { makeStyles } from '@material-ui/core/styles';
import clsx from  'clsx';

const useStyles = makeStyles((theme) => ({
  consoleOutput: {
    backgroundColor:"black",
    paddingLeft: theme.spacing(4),
    paddingRight: theme.spacing(4),
    overflow: "auto",
    minHeight: "500px",
    maxHeight: "500px",
    width: "100%",
    color: "white",
  },
  dialogOutput: {
    backgroundColor:"black",
    paddingLeft: theme.spacing(4),
    paddingRight: theme.spacing(4),
    overflow: "auto",
    minHeight: "500px",
    width: "100%",
    color: "white",
  },
}));

export function ConsoleOutput({html, dataReady, extraClass, shownInDialog}) {
  const classes = useStyles();
  const stdoutRef = useRef(null);
  const [firstTime, setFirstTime] = useState(true);
  const [autoScrollEnabled, setAutoScrollEnabled] = useState(true);

  const [y, setY] = useState(0);

  var styleClass;

  useEffect(() => {
    function scrollDown() {
      if (stdoutRef.current) {
        stdoutRef.current.scrollTop = stdoutRef.current.scrollHeight;
        if (firstTime && dataReady) {
          setFirstTime(false);
        }
      }
    }

    if (autoScrollEnabled) {
      scrollDown();
    }
  }, [dataReady, firstTime, autoScrollEnabled]);

  const handleScroll = (e) => {
    const pane = e.currentTarget;
    if (y > pane.scrollTop) {
      // Scroll up event
      setAutoScrollEnabled(false);
    } else if ( pane.scrollHeight - pane.scrollTop === pane.clientHeight) {
      // Scroll to bottom
      setAutoScrollEnabled(true);
    }
    setY(pane.scrollTop);
  };

  if (shownInDialog) {
    styleClass = classes.dialogOutput;
  } else {
    styleClass = classes.consoleOutput;
  }

  return(
    <div onScroll={handleScroll}
      ref={stdoutRef}
      className={ clsx(styleClass, extraClass) }
      dangerouslySetInnerHTML={{ __html: html }}/>
  )
}