import React, { useState, useEffect } from "react";
import moment from 'moment';

export function formatToList(items) {

    if(!items) return null;

    return (
        <ul style={{ padding: 0 }}>
            {items.map((item) => (
                <li style={{ listStylePosition: 'inside' }} key={item}>{item}</li>
            ))}
        </ul>
    )
}

export function searchInArray(array, searchText) {
    if(array) {
        const found = array.find(element => element.toLowerCase().includes(searchText) );

        return found;
    }

    return false;
}

export const formatDate = (value) => {
    if (value) {
      return moment(value).format('DD/MM/YYYY HH:mm:ss');
    }
    return null;
}

export const formatDateOnly = (value) => {
  if (value) {
    return moment(value).format(dateFormat);
  }
  return null;
}

export const dateFormat = () => {
  return 'DD/MM/YYYY';
}

function getWindowDimensions() {
  const { innerWidth: width, innerHeight: height } = window;
  return {
    width,
    height
  };
}

export function useWindowDimensions() {
  const [windowDimensions, setWindowDimensions] = useState(getWindowDimensions());

  useEffect(() => {
    function handleResize() {
      setWindowDimensions(getWindowDimensions());
    }

    window.addEventListener('resize', handleResize);
    return () => window.removeEventListener('resize', handleResize);
  }, []);

  return windowDimensions;
}

export function parseHostUrl(url) {
  const hostName = url?.split('.', 2)[0];
  const network = url?.split('.', 2)[1];

  return {hostName: hostName, network: network?.includes('cslab') ? "CSLab" : (network?.includes('tn') ? "TN" : null)};
}

export function colorFromIndex(index) {
  const COLORS=[
    'rgba(66, 165, 245, 1)',
  'rgba(245, 132, 66, 1)',
  'rgba(245, 221, 66, 1)',
  'rgba(194, 66, 245, 1)',
  'rgba(100, 242, 75, 1)',
  'rgba(242, 75, 100, 1)',
  'rgba(75, 242, 192, 1)',
  'rgba(161, 168, 167, 1)',
  'rgba(37, 38, 38, 1)',
  'rgba(242, 162, 172, 1)',
  'rgba(172, 242, 162, 1)',
  'rgba(162, 242, 222, 1)'
  ];

  let n = COLORS.length;

  return COLORS[(index % n + n) % n];
}

export function backgroundColorFromIndex(index) {
  const COLORS=[
    'rgba(66, 165, 245, 0.2)',
  'rgba(245, 132, 66, 0.2)',
  'rgba(245, 221, 66, 0.2)',
  'rgba(194, 66, 245, 0.2)',
  'rgba(100, 242, 75, 0.2)',
  'rgba(242, 75, 100, 0.2)',
  'rgba(75, 242, 192, 0.2)',
  'rgba(161, 168, 167, 0.2)',
  'rgba(37, 38, 38, 0.2)',
  'rgba(242, 162, 172, 0.2)',
  'rgba(172, 242, 162, 0.2)',
  'rgba(162, 242, 222, 0.2)'];

  let n = COLORS.length;

  return COLORS[(index % n + n) % n];
}
export function iocHasNameDeviation(ioc) {
  
  if (!ioc.activeDeployment) {
    return false;
  }

  return ioc?.namingName !== ioc?.activeDeployment?.iocName;
}

export function applicationSubTitle() {
  const title = `${window.ENVIRONMENT_TITLE}`;

  if((title) && (title !== 'undefined')) {
    return ' - ' + title;
  }

  return '';
}
