import React from "react";
import { createContext, useEffect } from "react";
import { useDeploymentById, useCommandById } from '../../../api/SwaggerApi';

export const notificationContext = createContext({ deploymentNotifications: [], watchDeployment: ()=>{}, clearAll: ()=>{} });
export const WATCHED_DEPLOYMENT_IDS = "WATCHED_DEPLOYMENT_IDS";
export const DEPLOYMENT_NOTIFICATIONS = "DEPLOYMENT_NOTIFICATIONS";
export const WATCHED_COMMAND_IDS = "WATCHED_COMMAND_IDS";
const DEPLOYMENT_STATUS_POLL_INTERVAL = 3000;
const COMMAND_STATUS_POLL_INTERVAL = 1000;

export function NotificationProvider({ children }) {
  const [deployment, getDeployment] = useDeploymentById();
  const [command, getCommand] = useCommandById();

  const watchDeployment = (watchedDeploymentId) => watchId(watchedDeploymentId, WATCHED_DEPLOYMENT_IDS);
  const watchCommand = (watchedCommandId) => watchId(watchedCommandId, WATCHED_COMMAND_IDS);

  const watchId = (watchedId, storageKey) => {
    var watchedIds = JSON.parse(localStorage.getItem(storageKey));
    if (watchedIds) {
      if(!watchedIds.includes(watchedId)) {
        localStorage.setItem(storageKey, JSON.stringify([watchedId].concat(watchedIds)));
      }
    } else {
      localStorage.setItem(storageKey, JSON.stringify([watchedId]));
    }
  }

  function removeId(id, storageKey) {
    var watchedIds = JSON.parse(localStorage.getItem(storageKey));
    if (watchedIds) {
      var idsAfterRemove = watchedIds.filter(function(item){ 
          return item !== id; 
      });
      if (idsAfterRemove.length === 0) {
        localStorage.removeItem(storageKey);
      } else {
        localStorage.setItem(storageKey, JSON.stringify(idsAfterRemove));
      }
    }
  }

  const clearAll = () => {
    localStorage.removeItem(DEPLOYMENT_NOTIFICATIONS);
  } 

  function deploymentNotifications() {
    var notifications = JSON.parse(localStorage.getItem(DEPLOYMENT_NOTIFICATIONS));
    if (!notifications) {
      return [];
    }
    return notifications;
  }

  function setDeploymentNotifications(notifications) {
    localStorage.setItem(DEPLOYMENT_NOTIFICATIONS, JSON.stringify(notifications));
  }
 
  function getStoredIds(storageKey) {
    var ids = JSON.parse(localStorage.getItem(storageKey));
    return ids ? ids.map(Number) : [];
  }

  useEffect(() => {
    function removeDeploymentId(id) {
      removeId(id, WATCHED_DEPLOYMENT_IDS);
    }

    function appendNotifications(notification) {
      if (!deploymentNotifications().includes(notification)) {
        setDeploymentNotifications([notification].concat(deploymentNotifications()));
      }
    }

    const interval = setInterval(() => {
      const deploymentIds = getStoredIds(WATCHED_DEPLOYMENT_IDS);
      for (const deploymentId of deploymentIds) {
        getDeployment(deploymentId);
        if(deployment?.id === deploymentId && deployment?.status === "QUEUED") {
          appendNotifications((deployment.undeployment ? "Undeployment" : "Deployment") + " (" + deployment.id + ") for " + deployment.iocName + " is queued");
        } else if(deployment?.id === deploymentId && deployment?.status === "PENDING") {
          appendNotifications((deployment.undeployment ? "Undeployment" : "Deployment") + " (" + deployment.id + ") for " + deployment.iocName + " is pending");
        } else if(deployment?.id === deploymentId && deployment?.status === "RUNNING") {
          appendNotifications((deployment.undeployment ? "Undeployment" : "Deployment") + " (" + deployment.id + ") for " + deployment.iocName + " is running");
        } else if(deployment?.id === deploymentId && deployment?.status === "FAILED") {
          appendNotifications((deployment.undeployment ? "Undeployment" : "Deployment") + " (" + deployment.id + ") for " + deployment.iocName + " is failed");
          removeDeploymentId(deployment.id);
        } else if(deployment?.id === deploymentId && deployment?.status === "SUCCESSFUL") {
          appendNotifications((deployment.undeployment ? "Undeployment" : "Deployment") + " (" + deployment.id + ") for " + deployment.iocName + " is successful");
          removeDeploymentId(deployment.id);
        }
      }
    }, DEPLOYMENT_STATUS_POLL_INTERVAL);
    return () => clearInterval(interval);
  }, [deployment, getDeployment]);

  useEffect(() => {
    function removeCommandId(id) {
      removeId(id, WATCHED_COMMAND_IDS);
    }

    function appendNotifications(notification) {
      if (!deploymentNotifications().includes(notification)) {
        setDeploymentNotifications([notification].concat(deploymentNotifications()));
      }
    }

    const interval = setInterval(() => {
      const commandIds = getStoredIds(WATCHED_COMMAND_IDS);
      for (const commandId of commandIds) {
        getCommand(commandId);
        if(command?.id === commandId && command?.status === "PENDING") {
          appendNotifications(command.type + " command (" + command.id + ") for " + command.iocName + " is pending");
        } else if(command?.id === commandId && command?.status === "RUNNING") {
          appendNotifications(command.type + " command (" + command.id + ") for " + command.iocName + " is running");
        } else if(command?.id === commandId && command?.status === "FAILED") {
          appendNotifications(command.type + " command (" + command.id + ") for " + command.iocName + " is failed");
          removeCommandId(command.id);
        } else if(command?.id === commandId && command?.status === "SUCCESSFUL") {
          appendNotifications(command.type + " command (" + command.id + ") for " + command.iocName + " is successful");
          removeCommandId(command.id);
        }
      }
    }, COMMAND_STATUS_POLL_INTERVAL);
    return () => clearInterval(interval);
  }, [command, getCommand]);

  return (
    <notificationContext.Provider value={{ deploymentNotifications, watchDeployment, watchCommand, clearAll }}>
      {children}
    </notificationContext.Provider>
  );
}