import React from 'react';
import { makeStyles, withStyles } from '@material-ui/core/styles';
import clsx from 'clsx';
import {Stepper, Step, StepLabel, StepConnector, Hidden} from '@material-ui/core';
import { theme } from "../../../Theme";

const useStyles = makeStyles({
  stepper: {
      minWidth: 500,
      width: "100%",
  },
});

const useColorlibStepIconStyles = makeStyles({
  root: {
    backgroundColor: '#ccc',
    zIndex: 1,
    color: '#fff',
    width: 50,
    height: 50,
    display: 'flex',
    borderRadius: '50%',
    justifyContent: 'center',
    alignItems: 'center',
  },
  active: {
    background: theme.palette.status.progress,
    boxShadow: '0 4px 10px 0 rgba(0,0,0,.25)',
  },
  completed: {
    background: theme.palette.status.ok,
  },
  error: {
    background: theme.palette.status.fail,
  },
});

const ColorlibConnectorHorizontal = withStyles({
  alternativeLabel: {
    top: 22,
  },
  active: {
    '& $line': {
      background: theme.palette.status.progress,
    },
  },
  completed: {
    '& $line': {
      background: theme.palette.status.ok,
    },
  },
  line: {
    height: 3,
    border: 0,
    backgroundColor: '#eaeaf0',
    borderRadius: 1,
  },
})(StepConnector);

const ColorlibConnectorVertical = withStyles({
  alternativeLabel: {
    top: 22,
  },
  active: {
    '& $line': {
      background: theme.palette.status.progress,
    },
  },
  completed: {
    '& $line': {
      background: theme.palette.status.ok,
    },
  },
  line: {
    width: 4,
    border: 0,
    marginLeft: 11,
    backgroundColor: '#eaeaf0',
    borderRadius: 1,
  },
})(StepConnector);

export function StepperWithStyle({ steps, activeStep, isStepFailed, icons }) {
  const classes = useStyles(theme);

  function ColorlibStepIcon(props) {
    const classes = useColorlibStepIconStyles();
    const { active, completed, error } = props;

    return (
        <div
        className={clsx(classes.root, {
            [classes.active]: active,
            [classes.completed]: completed,
            [classes.error]: error,
        })}
        >
        {icons[String(props.icon)]}
        </div>
    );
  }

  return (
    <>
      <Hidden smUp>
        <Stepper className={classes.stepper} activeStep={activeStep}  orientation="vertical" connector={<ColorlibConnectorVertical />}>
          {steps.map((label, index) => {
            const labelProps = {};
            const stepProps = {};
            if (isStepFailed(index)) {
              labelProps.error = true;
              stepProps.error = true;
            }

            return (
            <Step key={label}>
              <StepLabel {...labelProps} StepIconComponent={ColorlibStepIcon}>{label}</StepLabel>
            </Step>
        )})}
      </Stepper>
      </Hidden>
      <Hidden xsDown>
        <Stepper className={classes.stepper} alternativeLabel activeStep={activeStep} connector={<ColorlibConnectorHorizontal />}>
          {steps.map((label, index) => {
            const labelProps = {};
            const stepProps = {};
            if (isStepFailed(index)) {
              labelProps.error = true;
              stepProps.error = true;
            }

            return (
            <Step key={label} {...stepProps}>
              <StepLabel {...labelProps} StepIconComponent={ColorlibStepIcon}>{label}</StepLabel>
            </Step>
          )})}
        </Stepper>
      </Hidden>
    </>
  );
}