import React from 'react';
import PropTypes from 'prop-types';
import { Paper } from '@material-ui/core';
import { DataTable } from 'primereact/datatable';
import { Column } from 'primereact/column';
import 'primeicons/primeicons.css';
import 'primereact/resources/themes/mdc-light-indigo/theme.css';
import 'primereact/resources/primereact.css';
import 'primeflex/primeflex.css';
import './CustomTable.css';

export function CustomTable(props) {
  const {columns, rows, handleRowClick, rowsPerPage} = props;

  const dynamicColumns = columns.map((col,i) => {
        return <Column key={col.id} field={col.id} header={col.label} style={{width: col.width}} body={col.body} sortable={col.sortable}/>;
    });

  const handleClick = (event) => {
    handleRowClick(event.data.id);
  };

  const rowClassName = (rowData) => {

    var resultObject = {};

    //if row is clickable -> change cursor by adding 'a new' className
    if (handleRowClick) {
      resultObject.isLink = true;
    }

    if (rowData.inconsistentState) {
      resultObject.inconsistentState = true;
      return resultObject;
    } else if (rowData.discrepancy) {
      resultObject.discrepancy = true;
      return resultObject;
    } else if (rowData.exporterUnknown) {
      resultObject.exporterUnknown = true;
      return resultObject;
    }

    return resultObject;
  }

  return (
    <div className="ccce-custom-table">
      <Paper>
        <DataTable
          className="p-ccce-custom-table"
          value={rows}
          stripedRows
          scrollable 
          resizableColumns 
          columnResizeMode="fit"
          paginator
          paginatorTemplate="CurrentPageReport FirstPageLink PrevPageLink PageLinks NextPageLink LastPageLink RowsPerPageDropdown"
          currentPageReportTemplate="Showing {first} to {last} of {totalRecords}" rows={rowsPerPage ?? 10} rowsPerPageOptions={[5,10,20,50]}
          rowHover
          onRowClick={(event) => handleClick(event)}
          rowClassName={rowClassName}
        >
          {dynamicColumns}
        </DataTable>
      </Paper>
    </div>
  );
}

CustomTable.propTypes = {
  columns: PropTypes.arrayOf(PropTypes.shape({id: PropTypes.string.isRequired})).isRequired,
  rows: PropTypes.array.isRequired,
  handleRowClick: PropTypes.func,
};