import React from 'react';
import { CustomTable } from "../common/table/CustomTable";
import { Box, Tooltip } from "@material-ui/core";
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { DeploymentStatusIcon, DeploymentTypeIcon } from './DeploymentIcons';
import { useHistory } from 'react-router';
import { formatDate, parseHostUrl } from '../common/Helper';

const formatDeploymentDate = (value) => {
    if (value) {
      return formatDate(value);
    }
    return "Not started yet";
}

const dateTemplate = (rowData) => {
    return formatDeploymentDate(rowData.start);
}

const columns = [
  { id: 'type', label: 'Type', width: '4%'},
  { id: 'status', label: 'Status', width: '5%'},
  { id: 'ioc', label: 'IOC Name', width: '14%', sortable: true },
  { id: 'host', label: 'Host', width: '13%', sortable: true },
  { id: 'network', label: 'Network', width: '11%', sortable: true },
  { id: 'user', label: 'User', width: '12%', sortable: true },
  { id: 'version', label: 'Git reference', width: '26%', sortable: true },
  { id: 'start', label: 'Start date', width: '15%', body: dateTemplate, sortable: true }
];

function createGitVersionField(version, shortVersion) {
  return(
    <Tooltip title={version} arrow enterDelay={400}>
              <label>{shortVersion}</label>
    </Tooltip>
  )
}

function createTableRow(deployment) {
  console.log(deployment);
  const {hostName, network} =  deployment.host ? parseHostUrl(deployment.host.host) : {name: null, network: null};

  return { 
    id:deployment.id,
    type:
      <Box display="flex" justifyContent="center" p={2} m={1}>
        <DeploymentTypeIcon type={deployment.undeployment ? "undeploy" : "deploy"}/>
      </Box>,
    status: 
      <Box display="flex" justifyContent="center" p={2} m={1}>
        <DeploymentStatusIcon status={deployment.status}/>
      </Box>,
    ioc: deployment.iocName,
    version: createGitVersionField(deployment.sourceVersion, deployment.sourceVersionShort), 
    host: hostName,
    network: deployment.host?.network ?? network, 
    user: deployment.createdBy,
    start: deployment.startDate,
  };
}

export function DeploymentsTable({deployments, rowsPerPage}) {
  const history = useHistory();

  const onRowClicked = (id) => {
    history.push(`/deployments/${id}`);
  };

  return (
    <CustomTable columns={columns} rows={deployments.map(deployment => createTableRow(deployment))} handleRowClick={onRowClicked} rowsPerPage={rowsPerPage}/>
  );
}

export function SearchableDeploymentsTable({ deployments, setQuery }) {
  const filter = (search) => {
    setQuery(search.toLowerCase());
    return (item) => {
      return true;
    }
  }

  const renderFilteredItems = (filteredDeployments) => {
    return (
        <DeploymentsTable deployments={filteredDeployments}/>
      );
  }

  return (
    <SearchBoxFilter items={deployments} filter={filter} render={renderFilteredItems}/>
  );
}