import React from 'react';
import { Box, Tooltip } from "@material-ui/core";
import { CustomTable } from '../common/table/CustomTable';
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { useHistory } from 'react-router-dom';
import { HostStatusIcon } from './HostIcons';


const columns = [
    { id: 'bulb', label: 'Status', width: '6%' },
    { id: 'host', label: 'Host', width: '24%' },
    { id: 'description', label: 'Description', width: '28%' },
    { id: 'network', label: 'Network', width: '15%' },
    { id: 'scope', label: 'Scope', width: '15%' },
    { id: 'deviceType', label: 'Device Type', width: '12%' },
];

export function rowDescription(description) {

    return(
        <div className={'shortenLongDataLines'}>
            <Tooltip title={description} arrow enterDelay={400}>
                <label>{description}</label>
            </Tooltip>
        </div>
    );
}

export function createRow(hostContainer) {
    const host = hostContainer.csEntryHost;
    return {
        id: host.id,
        bulb: 
          <Box display="flex" justifyContent="left" paddingX={1} m={1}>
            <HostStatusIcon host={hostContainer} />
          </Box>,
        host: host.name,
        description: rowDescription(host.description),
        network: host.interfaces[0]?.network,
        deviceType: host.device_type,
        scope: host.scope,
        shortenLongData: true,
    };

}


export function HostsTable({ hosts }) {
    const history = useHistory();

    console.log(hosts);

    const onRowClicked = (id) => {
        history.push(`/hosts/${id}`);
    };

    return <CustomTable columns={columns} rows={hosts.map(host => createRow(host))} handleRowClick={onRowClicked} />;
}

export default function HostTable({ hosts, setQuery }) {
    const filter = (search) => {
        setQuery(search.toLowerCase());
        return (hostContainer) => {
            return true;    
        }
    }

    const renderFilteredHosts = (filteredHosts) => <HostsTable hosts={filteredHosts} />;

    return (
        <SearchBoxFilter items={hosts} filter={filter} render={renderFilteredHosts} />
    );
}