import { Grid, Paper, Tab, Tabs, Typography, IconButton } from "@material-ui/core";
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import React, { useEffect, useState } from "react";
import { useIOC } from "../../api/SwaggerApi";
import { IOCLiveStatus } from "../../components/IOC/IOCLiveStatus";
import { IOCManage } from "../../components/IOC/IOCManage";
import { useHistory } from "react-router-dom";
import IOCAdmin from "../../components/IOC/IOCAdmin";
import AccessControl from "../../components/auth/AccessControl";

export function IOCDetailsView({ id }) {
  const [selectedTab, setSelectedTab] = useState("Manage deployment");
  const [firstTime, setFirstTime] = useState(true);
  const [ioc, getIOC] = useIOC(id);
  const history = useHistory();
  console.log(ioc);

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };

  useEffect(() => {
    if (firstTime && ioc && ioc.activeDeployment) {
      setSelectedTab("Live Status");
      setFirstTime(false);
    }
  }, [ioc, firstTime]);

  const handleClick = () => {
    history.goBack();
  };

  function resetTab() {
    if (ioc && ioc.activeDeployment) {
      setSelectedTab("Live Status");
    } else {
      setSelectedTab("Manage deployment");
    }
  }

  return (
    <Paper>
      <Grid container spacing={1}>
        <Grid item xs={1}>
          <IconButton color="inherit" onClick={handleClick}>
            <ArrowBackIcon />
          </IconButton>
        </Grid>
        <Grid item xs={11}>
          <Grid container justify="center">
            <AccessControl allowedRoles={["DeploymentToolAdmin"]}
              renderNoAccess={() =>
                <Tabs
                  value={selectedTab}
                  onChange={handleTabChange}
                  indicatorColor="primary"
                  textColor="primary"
                >
                  {ioc && ioc.activeDeployment && <Tab label={<Typography variant="h5">Live Status</Typography>} value="Live Status" />}
                  {ioc && <Tab label={<Typography variant="h5">Manage deployment</Typography>} value="Manage deployment" />}
                </Tabs>
              }>
                
              <Tabs
                value={selectedTab}
                onChange={handleTabChange}
                indicatorColor="primary"
                textColor="primary"
              >
                {ioc && ioc.activeDeployment && <Tab label={<Typography variant="h5">Live Status</Typography>} value="Live Status" />}
                {ioc && <Tab label={<Typography variant="h5">Manage deployment</Typography>} value="Manage deployment" />}
                {ioc && <Tab label={<Typography variant="h5">IOC Admin</Typography>} value="IOC Admin" />}
              </Tabs>
            </AccessControl>
          </Grid>
        </Grid>
        <Grid item xs={12} style={{ paddingBottom: 0 }}>
          {selectedTab === "Live Status" && <IOCLiveStatus ioc={ioc} getIOC={getIOC} />}
          {selectedTab === "Manage deployment" && <IOCManage ioc={ioc} getIOC={getIOC} />}
          {selectedTab === "IOC Admin" && <IOCAdmin ioc={ioc} getIOC={getIOC} resetTab={resetTab}/>}
        </Grid>
      </Grid>
    </Paper>
  );
}