import { Container, Grid, Hidden, Paper } from "@material-ui/core";
import { RootContainer } from "../../components/common/Container/RootContainer";
import React, { useState, useEffect } from "react"
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { SearchableIOCList } from "../../components/IOC/IOCList";
import { SearchableIOCTable } from "../../components/IOC/IOCTable";
import { useIOCSearch } from "../../api/SwaggerApi";
import { makeStyles } from '@material-ui/core/styles';

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
}));

export function IOCListView() {
  const [iocs, getIocs] = useIOCSearch();
  const [query, setQuery] = useState();
  const classes = useStyles();

  useEffect(() => getIocs(`${query}`), [query, getIocs]);

  console.log("rendering Explore IOCs")

  const title = "Explore IOCs";
  useGlobalAppBar(title);

  function preProcess(iocs) {
    console.log(iocs);
    const abcIOCs = iocs.sort((a, b) => a.namingName.localeCompare(b.namingName));
    return abcIOCs;
  }

  let content = (
    <>
      <Hidden smUp>
        <SearchableIOCList iocs={preProcess(iocs)} setQuery={setQuery}/>
      </Hidden>
      <Hidden xsDown>
        <SearchableIOCTable iocs={preProcess(iocs)} setQuery={setQuery} rowType="explore"/>
      </Hidden>
    </>
  );

  return (
    <RootContainer>
      <Container>
        <Paper className={classes.root}>
          <Grid container spacing={1}>
            <Grid item xs={12}>
              {content}
            </Grid>
          </Grid>
        </Paper>
      </Container>
    </RootContainer>
  );
}

