import React, { useState, useEffect } from 'react';
import {
    Paper,
    Link,
    Container,
    Hidden,
    IconButton,
    Button,
    Card,
    CardContent,
    Typography,
} from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import { useHost, useHostIOCList, } from '../../api/SwaggerApi';
import { HostBadge } from '../../components/host/HostBadge';
import { SimpleAccordion } from '../../components/common/Accordion/SimpleAccordion';
import { SearchableIOCList } from '../../components/IOC/IOCList';
import { SearchableIOCTable } from '../../components/IOC/IOCTable';
import { KeyValueTable } from '../../components/common/KeyValueTable/KeyValueTable';
import { LokiPanel } from '../../components/common/Loki/LokiPanel';
import { useHistory } from "react-router-dom";
import { formatDate } from '../../components/common/Helper';
import { Launch } from '@material-ui/icons';
import { LokiDialog } from '../../components/common/Loki/LokiDialog';
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";

const useStyles = makeStyles((theme) => ({
    secondItem: {
        marginTop: theme.spacing(2),
    },
}));

export function HostDetailsView({ id }) {
    const [host] = useHost(id);
    const [iocs] = useHostIOCList(id);
    const [query, setQuery] = useState();
    const [deployedIocs, setDeployedIocs] = useState([]);
    const history = useHistory();
    const classes = useStyles();
    const [logDialogOpen, setLogDialogOpen] = useState(false);
    console.log({ ...iocs });
    console.log({ ...host });

    useEffect(() => setDeployedIocs((iocs?.deployed ?? []).filter(ioc => ioc.namingName.toLowerCase().includes(query) ||
        (ioc.host && ioc.host.toLowerCase().includes(query)) ||
        ioc.git.toLowerCase().includes(query) ||
        ioc.version.toLowerCase().includes(query) ||
        ioc.owner.toLowerCase().includes(query) ||
        (ioc.status && ioc.status.toLowerCase().includes(query)))), [query, iocs]);

    const renderHost = { ...host?.csEntryHost };
    delete renderHost.id;
    renderHost.interfaces = <pre>{JSON.stringify(host?.csEntryHost?.interfaces, null, 2)}</pre>;
    renderHost.ansible_vars = <pre>{JSON.stringify(host?.csEntryHost?.ansible_vars, null, 2)}</pre>
    renderHost.ansible_groups = <pre>{JSON.stringify(host?.csEntryHost?.ansible_groups, null, 2)}</pre>
    const createdAt = renderHost.created_at;
    delete renderHost.created_at;
    renderHost["created at"] = formatDate(createdAt);

    const closeLogDialogModal = () => {
        setLogDialogOpen(false);
    }

    const onDialogPopUp = () => {
        setLogDialogOpen(true);
    }

    const handleClick = (event) => {
        history.goBack();
    };

    return (
        <Paper>
            <SimpleModal open={logDialogOpen} setOpen={setLogDialogOpen}>
                <LokiDialog open={logDialogOpen} setOpen={setLogDialogOpen} submitCallback={closeLogDialogModal} host={host} isSyslog={true} isDeployed={true} />
            </SimpleModal>
            <IconButton color="inherit" onClick={handleClick}>
                <ArrowBackIcon />
            </IconButton>
            {host && <HostBadge host={host} />}
            <SimpleAccordion summary="Deployed IOCs" defaultExpanded>
                <Hidden smUp>
                    <SearchableIOCList iocs={deployedIocs} setQuery={setQuery} />
                </Hidden>
                <Hidden xsDown>
                    <SearchableIOCTable iocs={deployedIocs} setQuery={setQuery} rowType="host" />
                </Hidden>
            </SimpleAccordion>
            <SimpleAccordion summary="Syslog info" defaultExpanded>
                {host &&
                    <Container>
                        <Button color="inherit" variant="outlined" endIcon={<Launch />} style={{ float: 'right' }} onClick={onDialogPopUp}>Popout log</Button>
                        <LokiPanel host={host} isSyslog={true} isDeployed={true} />
                    </Container>}
            </SimpleAccordion>
            <Card variant="outlined">
                <CardContent>
                    <Container>
                        <Typography variant="h6">
                            Open in CSEntry
                        </Typography>
                        <Link href={`https://csentry.esss.lu.se/network/hosts/view/${host?.csEntryHost.name}`} target="_blank" rel="noreferrer">{`https://csentry.esss.lu.se/network/hosts/view/${host?.csEntryHost?.name}`}</Link>

                        <Typography variant="h6" className={classes.secondItem}>
                            Open in Grafana
                        </Typography>
                        <Link href={`https://grafana.tn.esss.lu.se/d/5zJT23xWz/node-exporter-full?orgId=1&var-node=${host?.csEntryHost.fqdn}`} target="_blank" rel="noreferrer">{`https://grafana.tn.esss.lu.se/d/5zJT23xWz/node-exporter-full?orgId=1&var-node=${host?.csEntryHost.fqdn}`}</Link>
                    </Container>
                </CardContent>
            </Card>
            <SimpleAccordion summary="CSEntry Configuration">

                {host && <KeyValueTable obj={renderHost} variant="table" />}
            </SimpleAccordion>
        </Paper>
    );
}