import React, { useEffect, useState } from "react";
import {
    Paper,
    Grid,
    Hidden,
    Container
} from '@material-ui/core';
import { RootContainer } from "../../components/common/Container/RootContainer";
import HostList from '../../components/host/HostList';
import HostTable from '../../components/host/HostTable';
import { useCSEntrySearch } from "../../api/SwaggerApi";
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { makeStyles } from '@material-ui/core/styles';

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
}));

export function HostListView() {
    useGlobalAppBar("Explore IOC hosts");

    const [hosts, getHosts] = useCSEntrySearch();
    const [query, setQuery] = useState();
    const classes = useStyles();

    useEffect(() => getHosts(`fqdn:"${query}"`), [query, getHosts]);    

    const content = (
        <>
            <Hidden smUp>
                <HostList hosts={hosts} setQuery={setQuery}/>
            </Hidden>
            <Hidden xsDown>
                <HostTable hosts={hosts} setQuery={setQuery}/>
            </Hidden>
        </>
    );

    return (
        <RootContainer>
            <Container>
                <Paper className={classes.root}>
                    <Grid container spacing={1} justify="flex-end">
                        <Grid item xs={12} md={12}>
                            {content}
                        </Grid>
                    </Grid>
                </Paper>
            </Container>
        </RootContainer>
    );
}